@@ -86,8 +86,10 @@ get_mp3 <- function(id,
       stop(msg)
     }
   )
-  
-  if (1 %in% ret) return(invisible(NULL))
+
+  if (1 %in% ret) {
+    return(invisible(NULL))
+  }
 
   f <- listfiles(getwd(), recursive = FALSE) %>%
     filter(grepl("\\.info\\.json", .data$filename)) %>%
